diff --git a/felamimail/inc/class.felamimail_hooks.inc.php b/felamimail/inc/class.felamimail_hooks.inc.php
index 905ea781a0..0704cf879e 100644
--- a/felamimail/inc/class.felamimail_hooks.inc.php
+++ b/felamimail/inc/class.felamimail_hooks.inc.php
@@ -893,7 +893,7 @@ class felamimail_hooks
$selectAccount = html::select('accountSelect', $selectedID, $identities, true, 'id="accountSelect" style="width:99.5%;" onchange="var appWindow=egw_appWindow(\''.$appname.'\');appWindow.changeActiveAccount(this);"',0,false);
//error_log(__METHOD__.__LINE__.$selectAccount);
$file[] = array(
- 'text' => "
".$selectAccount."
",
+ 'text' => "".$selectAccount."
",
'no_lang' => True,
'link' => False,
'icon' => False,
diff --git a/felamimail/inc/class.uicompose.inc.php b/felamimail/inc/class.uicompose.inc.php
index 69d0240d9a..0b858edc1a 100644
--- a/felamimail/inc/class.uicompose.inc.php
+++ b/felamimail/inc/class.uicompose.inc.php
@@ -502,7 +502,7 @@
$this->t->set_var("link_action",egw::link('/index.php',$linkData));
$this->t->set_var('folder_name',$this->bofelamimail->sessionData['mailbox']);
$this->t->set_var('compose_id',$this->composeID);
- // the editorobject is needed all the time (since we use CKEDITOR3
+ // the editorobject is needed all the time (since we use CKEDITOR
//$editorObject = html::initCKEditor('400px','simple');
$this->t->set_var('ckeditorConfig', egw_ckeditor_config::get_ckeditor_config('simple-withimage'));//$editorObject->jsEncode($editorObject->config));
$this->t->set_var('refreshTimeOut', 3*60*1000); // 3 minutes till a compose messages will be saved as draft;
@@ -824,7 +824,7 @@
function display_app_header()
{
egw_framework::validate_file('jscode','composeMessage','felamimail');
- egw_framework::validate_file('ckeditor3','ckeditor','phpgwapi');
+ egw_framework::validate_file('ckeditor','ckeditor','phpgwapi');
$GLOBALS['egw']->js->set_onload('javascript:initAll();');
$GLOBALS['egw']->js->set_onbeforeunload("if (do_onunload && justClickedSend==false) if (draftsMayExist) {a = checkunload(browserSupportsOnUnloadConfirm?'".addslashes(lang("Please choose:"))."'+'\\n'+'".addslashes(lang("1) keep drafted message (press OK)"))."'+'\\n'+'".addslashes(lang("2) discard the message completely (press Cancel)"))."':'".addslashes(lang("if you leave this page without saving to draft, the message will be discarded completely"))."');".' if (!browserSupportsOnUnloadConfirm) return a;}');
diff --git a/phpgwapi/inc/class.html.inc.php b/phpgwapi/inc/class.html.inc.php
index 4b6c32716e..f3ab958cfe 100644
--- a/phpgwapi/inc/class.html.inc.php
+++ b/phpgwapi/inc/class.html.inc.php
@@ -510,7 +510,7 @@ class html
}
//include the ckeditor js file
- egw_framework::validate_file('ckeditor3','ckeditor','phpgwapi');
+ egw_framework::validate_file('ckeditor','ckeditor','phpgwapi');
// run content through htmlpurifier
if ($_purify && !empty($_content))
@@ -535,7 +535,7 @@ class html
return self::textarea($_name,$_content,'id="'.htmlspecialchars($_name).'"',true). // true = double encoding
'
-
-
-
diff --git a/phpgwapi/inc/class.egw_ckeditor_config.inc.php b/phpgwapi/inc/class.egw_ckeditor_config.inc.php
index 30c21e5c3c..c9c5bde31d 100644
--- a/phpgwapi/inc/class.egw_ckeditor_config.inc.php
+++ b/phpgwapi/inc/class.egw_ckeditor_config.inc.php
@@ -18,7 +18,7 @@ class egw_ckeditor_config
private static $enterMode = null;
private static $skin = null;
// Defaults, defined in phpgwapi/js/ckeditor3/_source/plugins/font/plugin.js
public static $font_options = array(
'arial, helvetica, sans-serif' => 'Arial',
'Comic Sans MS, cursive' => 'Comic Sans MS',
@@ -120,7 +120,7 @@ class egw_ckeditor_config
private static function get_base_path()
{
//Get the ckeditor base url
- return $GLOBALS['egw_info']['server']['webserver_url'].'/phpgwapi/js/ckeditor3/';
+ return $GLOBALS['egw_info']['server']['webserver_url'].'/phpgwapi/js/ckeditor/';
}
/**
@@ -168,19 +168,18 @@ class egw_ckeditor_config
switch ($skin)
{
case 'silver':
- $skin = "v2";
- break;
+ case 'office2003':
case 'default':
$skin = "kama";
break;
- case 'office2003':
- $skin = "office2003";
+ case 'moono':
+ $skin = "moono";
break;
}
//Check whether the skin actually exists, if not, switch to a default
if (!(file_exists($basePath.'skins/'.$skin) || file_exists($skin) || !empty($skin)))
- $skin = "office2003";
+ $skin = "kama";
self::$skin = $skin;
}
@@ -18,7 +18,7 @@ class egw_ckeditor_config
private static $enterMode = null;
private static $skin = null;
- // Defaults, defined in phpgwapi/js/ckeditor3/_source/plugins/font/plugin.js
+ // Defaults, defined in phpgwapi/js/ckeditor/plugins/font/plugin.js
public static $font_options = array(
'arial, helvetica, sans-serif' => 'Arial',